@@ -2,6 +2,7 @@ import json
 import re
 import requests
 import os
+import enum
 from urllib.parse import urlparse, urljoin, quote
 from datetime import date, datetime
 from dateutil.relativedelta import relativedelta
@@ -20,19 +21,37 @@ from .utils import (
 )
 
 
+class GroupType(enum.Enum):
+    """Available group types in IAM"""
+
+    LZ = "lz"  # Leitzahl group
+    CUSTOM = "custom"  # default security group
+    REALM = "realm"  # VPN realm
+    PRIVATE = "private"  # User private group
+
+
+class GroupSearchField(enum.Enum):
+    NAME = "cn"
+    GID_NUMBER = "gidNumber"
+    DESCRIPTION = "description"
+    MEMBER = "memberUid"
+
+
 class ETH_IAM_conn:
     def __init__(
         self,
         admin_username=None,
         admin_password=None,
+        hostname_legacy="https://idn.ethz.ch",
         hostname="https://iam.passwort.ethz.ch",
         hostname_new="https://iamws.ethz.ch",
         endpoint_base="/iam-ws-legacy",
         endpoint_base_new="/",
-        verify_certificates=True,
+        verify_certificates: bool = True,
     ):
         self._admin_username = admin_username or self.get_username()
         self._admin_password = admin_password or self.get_password()
+        self.hostname_legacy = hostname_legacy
         self.hostname = hostname
         self.hostname_new = hostname_new
         self.endpoint_base = endpoint_base
@@ -259,6 +278,13 @@ class ETH_IAM_conn:
         data = self.get_request(endpoint=endpoint)
         return User(conn=self, data=data)
 
+    def get_users_of_lz(self, lz):
+        endpoint = f"/users/host_lz/{lz}"
+        data = self.get_request(
+            hostname=self.hostname_legacy, endpoint=endpoint, endpoint_base="usermgr"
+        )
+        return data
+
     def get_guest(self, username: str) -> Guest:
         data = self.get_request(
             f"/guests/{username}",
@@ -518,7 +544,7 @@ class ETH_IAM_conn:
             data = json.loads(resp.content.decode())
             raise ValueError(data["message"])
 
-    def get_groups(self, **kwargs):
+    def get_groups(self, type_: GroupType = None, **kwargs):
         """
         agroup=<Admin Group>  -- Get all groups of a given admin group
         name=group_name*      -- all groups starting with «group_name*»
