@@ -1,12 +1,11 @@
-import datetime
 import getpass
 import json
 import os
-import re
 
 import click
 import yaml
 from click.exceptions import ClickException
+from requests import ConnectionError
 
 from ethz_iam_webservice.utils import to_date
 
@@ -61,12 +60,6 @@ def login(
 ):
     hostname = hostname
 
-    config_path = os.path.join(os.path.expanduser("~"), ".ethz_iam")
-    if os.path.exists(config_path):
-        import configparser
-
-        raise Exception("not yet implemented")
-
     if admin_username is None:
         admin_username = os.environ.get(
             "IAM_USERNAME", input("Enter the admin username: ")
@@ -148,7 +141,10 @@ def person(
     get_username_password(ctx)
 
     e = login(ctx.obj["username"], ctx.obj["password"], ctx.obj["hostname"])
-    person = e.get_person(person)
+    try:
+        person = e.get_person(person)
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
 
     if add_user and username:
         info = {
@@ -238,18 +234,26 @@ def group(
     e = login(ctx.obj["username"], ctx.obj["password"], ctx.obj["hostname"])
     if new:
         if not agroup:
-            raise click.ClickException("Please provide an admin group with --agroup")
+            raise ClickException("Please provide an admin group with --agroup")
         try:
             group = e.new_group(
                 name=group, admingroup=agroup, description=description, targets=target
             )
         except ValueError as exc:
             raise ClickException(exc)
+        except ConnectionError as exc:
+            raise ClickException(
+                f"Cannot connect to IAM webservice at {exc.request.url}"
+            )
     else:
         try:
             group = e.get_group(group)
         except ValueError as exc:
             raise ClickException(exc)
+        except ConnectionError as exc:
+            raise ClickException(
+                f"Cannot connect to IAM webservice at {exc.request.url}"
+            )
 
     if add:
         group.add_members(*add)
@@ -276,6 +280,18 @@ def guest(ctx):
     ctx.obj["iam"] = iam
 
 
+@guest.command("list", help="return all guest users of a given host leitzahl")
+@click.argument("leitzahl")
+@click.pass_context
+def get_guests(ctx, leitzahl):
+    iam = ctx.obj["iam"]
+    try:
+        guests = iam.get_users_of_lz(leitzahl)
+    except Exception as exc:
+        raise ClickException(exc)
+    click.echo(json.dumps(guests, indent=4, sort_keys=True))
+
+
 @guest.command("get", help="get an existing guest")
 @click.argument("username")
 @click.pass_context
@@ -283,8 +299,8 @@ def get_guest(ctx, username):
     iam = ctx.obj["iam"]
     try:
         guest = iam.get_guest(username)
-    except Exception as exc:
-        raise click.ClickException(exc)
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
     print(json.dumps(guest._data_formatted(), indent=4, sort_keys=True))
 
 
@@ -305,7 +321,7 @@ def extend_guest(ctx, enddate, months, username):
         guest = iam.extend_guest(username, enddate, months)
         print(json.dumps(guest._data_formatted(), indent=4, sort_keys=True))
     except Exception as exc:
-        raise click.ClickException(exc)
+        raise ClickException(exc)
 
 
 @click.option("-d", "--description", help="")
@@ -330,6 +346,7 @@ def extend_guest(ctx, enddate, months, username):
     "--notification",
     help="g=guest, h=host, t=technical contact. Use any combination of the 3 chars. Defaults to «gh»",
 )
+@click.option("-m", "--email", "--mail", help="Change email address of the guest")
 @click.option(
     "-s", "--startDate", help="Start date of guest (YYYY-DD-MM). Default: today"
 )
@@ -355,6 +372,7 @@ def update_guest(
     technicalcontact,
     admingroup,
     notification,
+    email,
     startdate,
     enddate,
     username,
@@ -386,8 +404,8 @@ def update_guest(
             deactivationEndDate=deactivationenddate,
         )
         print(json.dumps(guest._data_formatted(), indent=4, sort_keys=True))
-    except Exception as exc:
-        raise click.ClickException(exc)
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
 
 
 @guest.command("new", help="create a new guest")
@@ -470,8 +488,8 @@ def new_guest(
             endDate=enddate,
         )
         guest.save()
-    except Exception as exc:
-        raise click.ClickException(exc)
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
 
     ldap_password = gen_password()
     vpn_password = gen_password()
@@ -479,7 +497,7 @@ def new_guest(
     guest_username = guest_data.get("username")
 
     if not guest_username:
-        click.ClickException(
+        ClickException(
             "could not set inital password for the guest because the guest has no username."
         )
 
@@ -557,7 +575,10 @@ def user(
 ):
     get_username_password(ctx)
     e = login(ctx.obj["username"], ctx.obj["password"], ctx.obj["hostname"])
-    user = e.get_user(username)
+    try:
+        user = e.get_user(username)
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
 
     if delete:
         click.confirm("Do you really want to delete this user?", abort=True)
