@@ -24,13 +24,17 @@ class User:
         self.username = None
         self.npid = None
         if data:
-            for service in data.get("services",[]):
-                service["login_until"] = to_date(service["login_until"]).strftime("%Y-%m-%d")
-                service["delete_after"] = to_date(service["delete_after"]).strftime("%Y-%m-%d")
+            for service in data.get("services", []):
+                service["login_until"] = to_date(service["login_until"]).strftime(
+                    "%Y-%m-%d"
+                )
+                service["delete_after"] = to_date(service["delete_after"]).strftime(
+                    "%Y-%m-%d"
+                )
             for key in data:
-                if key in ['valid_until', 'mod_date', 'cre_date']:
+                if key in ["valid_until", "mod_date", "cre_date"]:
                     d = to_date(data[key])
-                    data[key] = d.strftime('%Y-%m-%d')
+                    data[key] = d.strftime("%Y-%m-%d")
                 setattr(self, key, data[key])
 
     def __getitem__(self, key):
